==> TraPutty_v1.7.zip: README.md <==
とらぷてぃ。 v.1.7
==================

ウィンドウを透過するためのツールです。主にPuTTYをターゲットとしています。
起動するとタスクトレイに常駐するので、トレイアイコンをダブルクリックすると、PuTTYのウィンドウを透過させます。
右クリックすると起動しているアプリケーションの一覧が表示されるので、その中から任意の項目をクリックすることで、そのアプリケーションのウィンドウを透過することもできます。

一覧に表示されるアプリケーションは、プロセス名で表示されているので少し分かりづらいかもしれません。
マウスオーバーすると、アプリケーションのウィンドウタイトルがツールチップで表示されるので参考にして下さい。
現在既に透過されているアプリケーションは、チェックが付いた状態で表示され、末尾に * 印が付いています。
透過状態で、再びダブルクリックないしはメニュー項目を選択すると、透過状態を解除します。

また、トレイアイコンの右クリックメニューから、設定を選ぶと、透過度合いを0-254の間で設定できます。
値を小さくするほど透明度が増し、見えにくくなります。

設定は本アプリ終了時にTraPutty.xmlというファイルに保存されます。
このファイルを編集すると、NGリストを作ることができます。
NGリストに書かれた名前と一致したプロセス名のアプリケーションは、右クリックの一覧に表示されません。

NGリストに登録することで、本アプリが与える副作用を無くすことができます。
Windowsのガジェットや、Adobe Airで作られたアプリケーションなど、透過させると表示がおかしくなるアプリケーションもあります。
そういうアプリケーションのプロセス名をNGリストに載せれば、誤って透過処理を行ってしまうことを防ぐことができます。

詳しい使い方はこちらのページをご覧下さい。

* [yuuAn's Note / PuTTYのウィンドウを半透明にする方法]( http://www.yuuan.net/item/504 )


ライセンス
----------

ライセンスは修正BSDライセンスを適用します。
改変、再配布などする場合は、以下の条文に従って行って下さい。

```
License of とらぷてぃ。

Copyright (C) 2012-2014 yuuAn
All rights reserved.


1. ソースコード形式であれバイナリ形式であれ、変更の有無に関わらず、以下の条件を満たす限りにおいて、再配布および利用を許可します

  1-1. ソースコード形式で再配布する場合、上記著作権表示、本条件書および第2項の責任限定規定を必ず含めてください。
  1-2. バイナリ形式で再配布する場合、上記著作権表示、本条件書および下記責任限定規定を、配布物とともに提供される文書および/または他の資料に必ず含めてください。

2. 本ソフトウェアは無保証です。自己責任で使用してください。

3. 著作権者の名前を、広告や宣伝に勝手に使用しないでください。
```


更新履歴
--------

### v1.7

  * 設定ウィンドウを複数開けてしまうバグを修正
  * Alt + Tab のリストに表示されてしまうバグを修正

### v1.6

  * 設定を変更できないバグを修正
  * 著作権表示などのリンク先を変更

### v1.5

  * 英語で使用しているときの設定画面も透過しないようにできるようにした

### v1.4

  * PuTTYを透過するかどうかの状態を保存するようにした

### v1.3

  * NGリストに登録されたプロセスには全く触れないように修正

### v1.2

  * PuTTY設定を透過しないオプションを追加

### v1.1

  * 設定値を保存するようにした。
  * 新規に起動したPuTTYに対しても一括透過処理を行うようにした。
  * メニューで透過済みの項目がチェック状態で表示されるようにした。
  * NGリストを実装（仮）

### v1.0

  * リリース

==> TraPutty_v2.0.zip: README.md <==
とらぷてぃ。 v.2.0
==================

ウィンドウを透過するためのツールです。主にPuTTYをターゲットとしています。
起動するとタスクトレイに常駐するので、トレイアイコンをダブルクリックすると、PuTTYのウィンドウを透過させ、再びダブルクリックすることで透過状態を解除します。
トレイアイコンを右クリックすると、起動しているアプリケーションの一覧が表示されるので、その中から任意の項目をクリックすることで、そのアプリケーションのウィンドウを透過することもできます。

一覧に表示されるアプリケーションは、プロセス名で表示されているので少し分かりづらいかもしれません。
マウスオーバーすると、アプリケーションのウィンドウタイトルがツールチップで表示されるので参考にして下さい。
現在既に透過されているアプリケーションは、チェックが付いた状態で表示され、末尾に * 印が付いています。
透過状態で、再びメニュー項目を選択すると、透過状態を解除します。

また、トレイアイコンの右クリックメニューから、設定を選ぶと、透過度合いを0-254の間で設定できます。
値を小さくするほど透明度が増し、見えにくくなります。

設定は本アプリ終了時にTraPutty.xmlというファイルに保存されます。
このファイルを編集すると、NGリストを作ることができます。
NGリストに書かれた名前と一致したプロセス名のアプリケーションは、タスクトレイを右クリックした際に表示されるアプリケーションの一覧に表示されません。

NGリストに登録することで、本プログラムが与える副作用を無くすことができます。
Windowsのガジェットや、Adobe Airで作られたアプリケーションなど、透過させると表示がおかしくなるアプリケーションもあります。
そういうアプリケーションのプロセス名をNGリストに記載しておけば、本プログラムが透過状態の取得や設定を行わなくなりますし、誤って透過処理を行ってしまうことも防ぐことができます。

詳しい使い方はこちらのページをご覧下さい。

* [yuuAn's Note / PuTTYのウィンドウを半透明にする方法]( http://www.yuuan.net/item/504 )


ライセンス
----------

ライセンスは修正BSDライセンスを適用します。
改変、再配布などする場合は、以下の条文に従って行って下さい。

```
License of とらぷてぃ。

Copyright (C) 2012-2017 yuuAn
All rights reserved.


1. ソースコード形式であれバイナリ形式であれ、変更の有無に関わらず、以下の条件を満たす限りにおいて、再配布および利用を許可します

  1-1. ソースコード形式で再配布する場合、上記著作権表示、本条件書および第2項の責任限定規定を必ず含めてください。
  1-2. バイナリ形式で再配布する場合、上記著作権表示、本条件書および下記責任限定規定を、配布物とともに提供される文書および/または他の資料に必ず含めてください。

2. 本ソフトウェアは無保証です。自己責任で使用してください。

3. 著作権者の名前を、広告や宣伝に勝手に使用しないでください。
```


更新履歴
--------

### v2.0

  * 大規模なリファクタリング
  * 必要の無い情報を取得しないように修正
  * 透過度を設定する前に現在の値を確認して違っていた場合のみ適用するようにした

### v1.7

  * 設定ウィンドウを複数開けてしまうバグを修正
  * Alt + Tab のリストに表示されてしまうバグを修正

### v1.6

  * 設定を変更できないバグを修正
  * 著作権表示などのリンク先を変更

### v1.5

  * 英語で使用しているときの設定画面も透過しないようにできるようにした

### v1.4

  * PuTTYを透過するかどうかの状態を保存するようにした

### v1.3

  * NGリストに登録されたプロセスには全く触れないように修正

### v1.2

  * PuTTY設定を透過しないオプションを追加

### v1.1

  * 設定値を保存するようにした。
  * 新規に起動したPuTTYに対しても一括透過処理を行うようにした。
  * メニューで透過済みの項目がチェック状態で表示されるようにした。
  * NGリストを実装（仮）

### v1.0

  * リリース
